/*
 * Copyright (C) 2018 - Timo Könnecke <el-t-mo@arcor.de>
 *               2016 - Sylvia van Os <iamsylvie@openmailbox.org>
 *               2015 - Florent Revest <revestflo@gmail.com>
 *               2012 - Vasiliy Sorokin <sorokin.vasiliy@gmail.com>
 *                      Aleksey Mikhailichenko <a.v.mich@gmail.com>
 *                      Arto Jalkanen <ajalkane@gmail.com>
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.1
import org.freedesktop.contextkit 1.0
import org.asteroid.controls 1.0
import org.asteroid.utils 1.0

Item {

    Rectangle {
        id: dowBack
        z: 0
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: -parent.height*0.43
            horizontalCenter: parent.horizontalCenter
        }
        color: Qt.rgba(0, 0, 0, 0.5)
        width: parent.width
        height: parent.height * 0.085
    }

    Text {
        id: dowDisplay
        font.pixelSize: parent.height*0.08
        font.family: "Elektra"
        color: Qt.rgba(1, 0.933, 0.051, 0.8)
        horizontalAlignment: Text.AlignHCenter
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: -parent.height*0.43
            horizontalCenter: parent.horizontalCenter
        }
        text: Qt.formatDate(wallClock.time, "dddd")
    }

    Rectangle {
        id: dateBack
        z: 0
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: -parent.height*0.32
            horizontalCenter: parent.horizontalCenter
        }
        color: Qt.rgba(0, 0, 0, 0.5)
        width: parent.width
        height: parent.height * 0.085
    }

    Text {
        id: dateDisplay
        font.pixelSize: parent.height*0.08
        font.family: "Elektra"
        color: Qt.rgba(0.616, 1, 0.051, 0.8)
        horizontalAlignment: Text.AlignHCenter
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: -parent.height*0.32
            horizontalCenter: parent.horizontalCenter
        }
        text: Qt.formatDate(wallClock.time, "dd-MMM-yyyy")
    }

    Rectangle {
        z: 1
        id: timeBack
        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter
        color: Qt.rgba(0, 0, 0, 0.5)
        width: parent.width
        height: parent.height * 0.210
    }

    Text {
        z: 6
        id: hourDisplay
        renderType: Text.NativeRendering
        font.pixelSize: parent.height * 0.26
        font.family: "Elektra"
        font.letterSpacing: parent.width*0.01
        color: Qt.rgba(0.004, 1, 0.871, 0.8)
        horizontalAlignment: Text.AlignHCenter
        anchors {
            verticalCenter: parent.verticalCenter
            //verticalCenterOffset: parent.height*0.01
            horizontalCenter: parent.horizontalCenter
        }
        text: wallClock.time.toLocaleString(Qt.locale(), "HH:mm")
    }

    Text {
        z: 6
        id: secondDisplay
        renderType: Text.NativeRendering
        font.pixelSize: parent.height * 0.13
        font.family: "Elektra"
        font.styleName:"Thin"
        color: Qt.rgba(0.004, 1, 0.871, 0.8)
        horizontalAlignment: Text.AlignHCenter
        anchors {
            topMargin: parent.height * 0.025
            top: hourDisplay.top
            left: hourDisplay.right
            leftMargin: parent.width*0.005
        }
        //x: parent.width / 6 * 5.35 - width / 2
        text: wallClock.time.toLocaleString(Qt.locale(), "ss")
    }

    Text {
        id: apDisplay
        font.pixelSize: parent.height*0.08
        font.family: "Elektra"
        color: Qt.rgba(0.616, 1, 0.051, 0.8)
        horizontalAlignment: Text.AlignHCenter
        anchors {
            bottomMargin: parent.height * 0.046
            bottom: hourDisplay.bottom
            left: hourDisplay.right
            leftMargin: parent.width*0.005
        }
        text: wallClock.time.toLocaleString(Qt.locale(), "ap")
    }

    Rectangle {
        id: batteryBack
        z: 0
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: parent.height*0.32
            horizontalCenter: parent.horizontalCenter
        }
        color: Qt.rgba(0, 0, 0, 0.5)
        width: parent.width
        height: parent.height * 0.085
    }

    Text {
        id: batteryDisplay
        font.pixelSize: parent.height*0.08
        font.family: "Elektra"
        color: batteryChargePercentage.value < 30 ? 'red': Qt.rgba(0.318, 1, 0.051, 0.8)
        horizontalAlignment: Text.AlignHCenter
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: parent.height*0.32
            horizontalCenter: parent.horizontalCenter
        }
        text: batteryChargePercentage.value + "%   charged"
    }

    ContextProperty {
        id: batteryChargePercentage
        key: "Battery.ChargePercentage"
        value: "100"
        Component.onCompleted: batteryChargePercentage.subscribe()
    }
}
